def replaceDictIf(data, key, replacement):
    """Método para remplazar un valor de un diccionario en caso de que coincida con una llave
    Args:
        data (dict): Diccionario con los datos de entrada
        key (str): Llave del diccionario
        replacement (any): Valor por defecto

    Returns:
        any: Valor del diccionario o el valor por defecto
    """
    assert isinstance(data, dict)
    return str(data.get(key)).replace(" ", "") or replacement


def replaceIf(value, key, replacement):
    """Método para remplazar un valor en caso de que coincida con una llave

    Args:
        value (any): Valor a comparar
        key (any): Llave a comparar
        replacement (any): Valor por defecto

    Returns:
        any: Valor por defecto o el valor de entrada
    """    
    if value == key:
        return replacement
    return value



import json


def jsonConvert(data):
    return json.loads(json.dumps(data, indent=4, sort_keys=True, default=str))


def ErrorResponse(e):
    if isinstance(e, Exception):
        return {'data': None, 'state': False, 'code': e.args[0], 'message': e.args[1]}
    if isinstance(e, ValueError):
        return {'data': None, 'state': False, 'code': 500, 'message': e.args[0]}
    if isinstance(e, TypeError):
        return {'data': None, 'state': False, 'code': 500, 'message': e.args[0]}
    if isinstance(e, dict):
        return e
    print(str(e))
    error = eval(str(e))
    data = {'data': None, 'state': False,
            'code': error[0], 'message': error[1]}
    res = jsonConvert(data)
    return res


def Ok(e):
    if isinstance(e, dict):
        return {'data': e, 'state': True, 'code': None, 'message': None}
    if isinstance(e, list):
        l = []
        for i in e:
            l.append(json.loads(i))
        return {'data': l, 'state': True, 'code': None, 'message': None}
    data = e
    data = {'data': data, 'state': True, 'code': None, 'message': None}
    res = jsonConvert(data)
    return res


def getValue(input, key):
    data = input.get('data')
    if isinstance(data, dict):
        if key in data:
            return data[key]
        else:
            return None
    else:
        return None


if __name__ == '__main__':
    pass




class DataDto(object):
    """Clase de respuesta de la capa de Fachada Web

    Attributes:
        data (dict): Diccionario con los datos de la respuesta
        message (str): Mensaje de la respuesta
        code (int): Codigo de la respuesta
        state (bool): Estado de la respuesta
    """    
    def __init__(self, **kwargs):
        self.data = kwargs.get('data', None)
        self.message = kwargs.get('message', None)
        self.code = kwargs.get('code', None)
        self.state = kwargs.get('state', None)
    
    def __dict__(self):
        return {
            'data': self.data,
            'message': self.message,
            'code': self.code,
            'state': self.state
        }